﻿namespace CodeContractsDemo
{
    using System;
    using System.Collections.Generic;
    using System.Diagnostics.Contracts;

    public class PaymentProcessor
    {
        private readonly List<Payment> _payments = new List<Payment>();

        public void Add(Payment payment)
        {
            Contract.Requires(payment != null, "payment can't be null");
            Contract.Requires(payment.Name != null);
            Contract.Requires(payment.Date <= DateTime.Now);
            Contract.Requires(payment.Amount > 0);

            this._payments.Add(payment);
        }

        public void Add2(Payment[] payments)
        {
            Contract.Requires(
                (payments != null) &&
                Contract.ForAll(payments, payment => payment != null));

            foreach (var payment in payments) {
                this._payments.Add(payment);                
            }
        }

        public double GetPaymentsTotal(string name)
        {
            Contract.Requires(!string.IsNullOrWhiteSpace(name));

            Contract.Ensures(Contract.Result<double>() >= 0, "result can be less than zero");

            double total = 0.0;

            foreach (var payment in this._payments) {
                if (string.Equals(payment.Name, name)) {
                    total += payment.Amount;
                }
            }

            return total;
        }
    }
}